#!/bin/sh -efu

. shell-error
. install2-init-functions

# [ "$(stat -f -c %i $destdir)" != "$(stat -f -c %i $destdir/srv)" ] || exit 0

public='/srv/public'
shared='/srv/share'
nfsconf='/etc/sysconfig/nfs'
smbconf='/etc/samba/smb.conf'
servicedir='/etc/avahi/services'
vsftpcf='/etc/vsftpd/conf'
vsftpxi='/etc/xinetd.d/vsftpd'

mkdir -p "$destdir$public"
mkdir -p -m 1777 "$destdir$shared"

# nfs things
printf -- '%s -ro,insecure,no_subtree_check,fsid=1 *\n' "$public" > "$destdir/etc/exports"
printf -- '#%s -rw,insecure,fsid=0,sec=krb5 *\n' "$shared" >> "$destdir/etc/exports"
#[ ! -f "$destdir$nfsconf" ] || sed -i 's/^.\+SECURE_NFS.\+$/SECURE_NFS=yes/' "$destdir$nfsconf"

# smb
if [ -f "$destdir$smbconf" ] ; then
	mv "$destdir$smbconf" "$destdir$smbconf.orig"
	cat > "$destdir$smbconf" <<E_O_F
[global]
realm = REALM
server string = Samba server on %h (v. %v)
security = user
dedicated keytab file = /etc/krb5.keytab
kerberos method = dedicated keytab
log file = /var/log/samba/log.%m
max log size = 50
printcap name = cups
dns proxy = No
use sendfile = Yes
passdb backend = ldapsam:ldap://127.0.0.1/
ldap admin dn = cn=admin,dc=domain,dc=ru
ldap suffix = dc=domain,dc=ru
ldap group suffix = ou=Group
ldap user suffix = ou=People

[share]
comment = Commonplace
path = $shared
read only = No

[homes]
comment = Home Directory for '%u'
browseable = no
writable = yes
E_O_F
fi

# ftp ones
[ ! -d "$destdir/var/ftp" ] || fatal "/var/ftp already exists"
[ -f "$destdir$vsftpxi" ] || fatal "$vsftpxi is missing"

sed -i \
    -e '/^[[:blank:]]\+disable/ s/=.\+$/= no/' \
    -e '/only_from/d' \
    -e '/server_args/a\
	only_from	= 0/0' "$destdir$vsftpxi"

ln -s "..$public" "$destdir/var/ftp"

# avahi service declarations
[ -d "$destdir$servicedir" ] || fatal "$servicedir does not exists"
cat > "$destdir$servicedir/mirror.service" <<E_O_F
<service-group>
  <name replace-wildcards="no">mirror</name>
  <service>
    <type>_nfs._tcp</type>
    <port>2049</port>
    <txt-record>path=$public/mirror</txt-record>
    <txt-record>sec=sys</txt-record>
    <txt-record>options=hard,intr,nolock,ro</txt-record>
  </service>
</service-group>
E_O_F

[ ! -f "$destdir$smbconf" ] || cat > "$destdir$servicedir/samba.service" <<E_O_F
<service-group>
  <name replace-wildcards="yes">%h</name>
  <service>
    <type>_smb._tcp</type>
    <port>445</port>
    <txt-record>path=share</txt-record>
    <txt-record>logon_mount=yes</txt-record>
  </service>
</service-group>
E_O_F

cat > "$destdir$servicedir/anonftp.service" <<E_O_F
<service-group>
  <name replace-wildcards="yes">%h</name>
  <service>
    <type>_ftp._tcp</type>
    <port>21</port>
  </service>
</service-group>
E_O_F

# services
exec_chroot control rpcbind server
exec_chroot chkconfig rpcbind on
exec_chroot chkconfig nfslock on
exec_chroot chkconfig smb on
